# ../scripts/custom/gg_roundend_blocker/gg_roundend_blocker.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts Imports
#   ES
from es import getlivingplayercount
from es import ServerVar

# SPE Imports
from spe import detourFunction
from spe import undetourFunction
from spe import HookAction
from spe import HookType

# GunGame Imports
#   Addons
from gungame51.core.addons.info import AddonInfo
from gungame51.core.addons.loaded import LoadedAddons

# =============================================================================
# >> ADDON REGISTRATION/INFORMATION
# =============================================================================
info = AddonInfo()
info.name = 'gg_roundend_blocker'
info.title = 'GG RoundEnd Blocker'
info.author = 'Satoon101'
info.version = '1.1'

# =============================================================================
# >> PUBLIC VARIABLE
# =============================================================================
ServerVar(info.name + '_version', info.version,
        info.title + ' Version').set(info.version)
ServerVar(info.name + '_version').makepublic()


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():
    '''Executed on script load'''

    # Register the TerminateRound detour
    detourFunction('TerminateRound', HookType.Pre, roundend_blocker)


def unload():
    '''Executed on script unload'''

    # Unregister the TerminateRound detour
    undetourFunction('TerminateRound', HookType.Pre, roundend_blocker)


# =============================================================================
# >> REGISTERED CALLBACKS
# =============================================================================
def roundend_blocker(args):
    '''Prevents the round from ever ending'''

    # Is the server running Elim/FFA?
    if 'gg_ffa' in LoadedAddons and 'gg_elimination' in LoadedAddons:

        # Import respawn_players from Elimination
        from ...included.gg_elimination.modules.respawn import respawn_players

        # Is there exactly 1 living player?
        if getlivingplayercount() == 1:

            # Are any players set to respawn?
            if not respawn_players:

                # Allow the round to end
                return (HookAction.Continue, 0)

    # Prevent the round from ending
    return (HookAction.Override, 0)
